from GameVisionTargetingModel.models.classification.map.v1.setup.setup_of_input_layer \
    import generate_input_layer

from GameVisionTargetingModel.models.classification.map.v1.setup.setup_of_middle_layer \
    import generate_middle_layer

from GameVisionTargetingModel.models.classification.map.v1.setup.setup_of_output_layer \
    import generate_output_layer

from GameVisionTargetingModel.models.classification.map.v1.setup.setup_of_preprocessing \
    import generate_preprocessing_layers
